<?php
/**
 * Plugin Name: myCred Memberpress
 * Plugin URI: https://mycred.me
 * Description: Allows you integrate myCred with Memberpress
 * Version: 1.0.1
 * Tags: mycred, memberpress, integration
 * Author: myCRED
 * Author URI: http://mycred.me
 * Author Email: support@mycred.me
 * Requires at least: WP 4.8
 * Tested up to: WP 6.0
 * Text Domain: mycred_memberpress_integration
 * Domain Path: /lang
 * License: GPLv2 or later
 * License URI: http://www.gnu.org/licenses/gpl-2.0.html
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

include_once( ABSPATH . 'wp-admin/includes/plugin.php' );

if ( ! defined( 'ABSPATH' ) ) exit;

add_filter( 'mycred_setup_hooks', 'MycredMembr_purchase_a_specific_subs_product' );
function MycredMembr_purchase_a_specific_subs_product( $installed )
{
    $installed['specific_product'] = array(
        'title'       => __( 'MemberPress: Purchase Subscription Product', 'mycred_memberpress_integration' ),
        'description' => __( 'MemberPress: Purchase Subscription Product', 'mycred_memberpress_integration' ),
        'callback'    => array( 'MycredMembr_PurchaseASpecificSubsProduct' )
    );
    return $installed;
}

//Purchase OneTime/ Recurring Subscription
add_filter( 'mycred_setup_hooks', 'MycredMembr_purchase_product' );
if (!function_exists('MycredMembr_purchase_product'))
{
    function MycredMembr_purchase_product( $installed )
    {
        $installed['onetime_recurr'] = array(
            'title'       => __( 'MemberPress: Purchase OneTime/ Recurring Subscription Product', 'mycred_memberpress_integration' ),
            'description' => __( 'MemberPress: Purchase OneTime/ Recurring Subscription Product', 'mycred_memberpress_integration' ),
            'callback'    => array( 'MycredMembr_PurchaseSubsProduct' )
        );
        return $installed;
    }
}

if (!is_plugin_active('mycred/mycred.php'))
{
    echo '
    <div id="message" class="notice notice-warning is-dismissible">
        <p>Install and Active <a href="https://wordpress.org/plugins/mycred/" target="_blank">myCred</a>.</p>
        <button type="button" class="notice-dismiss">
            <span class="screen-reader-text">Dismiss this notice.</span>
        </button>
    </div>
    ';
}
elseif (!is_plugin_active('memberpress/memberpress.php'))
{
    echo '
    <div id="message" class="notice notice-warning is-dismissible">
        <p>Install and Active <a href="https://memberpress.com/" target="_blank">Memberpress</a>.</p>
        <button type="button" class="notice-dismiss">
            <span class="screen-reader-text">Dismiss this notice.</span>
        </button>
    </div>
    ';
}
else
{

    add_action('plugins_loaded', function (){
        if(!class_exists('MycredMembr_PurchaseASpecificSubsProduct')):
            class MycredMembr_PurchaseASpecificSubsProduct extends myCRED_Hook {

                /**
                 * Construct
                 * @param $hook_prefs
                 * @param string $type
                 */
                function __construct( $hook_prefs, $type = 'mycred_default' ) {
                    parent::__construct( array(
                        'id'       => 'specific_product',
                        'defaults' => array(
                            'creds'   => 1,
                            'log'     => '%plural% for Purchasing Subscription Product',
                            'limit'   => '1/d',
                            'product'   => 'Select Product'
                        )
                    ), $hook_prefs, $type );
                }

                /**
                 * Run
                 * @since 0.1
                 * @version 1.1
                 */
                public function run() {

                    // WordPress
                    add_action( 'mepr-event-transaction-completed', array( $this, 'purchased_specif_product' ), 10, 2 );

                }


                /**
                 * Login Hook
                 * @since 0.1
                 * @version 1.3
                 */

                public function purchased_specif_product( $event,$user_login = '' ) {
                    $user_ID = get_current_user_id();

                    $prefs = $this->prefs;
                    $transaction = $event->get_data();
                    $member_user = $transaction;

                    $user_subscription = $member_user->product_id;;

                    // Check for exclusion
                    if ( $this->core->exclude_user( $user_ID ) ) return;

                    if($prefs['product'] == $user_subscription)
                    {

                        // Limit
                        if ( ! $this->over_hook_limit( '', 'specific_subscription', $user_ID ) )
                            $this->core->add_creds(
                                'specific_subscription',
                                $user_ID,
                                $this->prefs['creds'],
                                $this->prefs['log'],
                                0,
                                '',
                                $this->mycred_type
                            );
                    }
                    elseif($prefs['product'] == 'all')
                    {
                        $is_first_real_payment = false;

                        if($transaction->amount > 0.00 ) {
                            $is_first_real_payment = true;
                        }
                        if($is_first_real_payment)
                        {
                            // Check for exclusion
                            if ( $this->core->exclude_user( $user_ID ) ) return;

                            // Limit
                            if ( ! $this->over_hook_limit( '', 'any_subscription', $user_ID ) )
                                $this->core->add_creds(
                                    'any_subscription',
                                    $user_ID,
                                    $this->prefs['creds'],
                                    $this->prefs['log'],
                                    0,
                                    '',
                                    $this->mycred_type
                                );
                        }
                    }
                    else
                    {
                        return;
                    }
                }
                /**
                 * Preference for Login Hook
                 * @since 0.1
                 * @version 1.2
                 */
                public function preferences() {
                    global $wpdb;
                    $table_name = $wpdb->prefix . 'posts';
                    $results = $wpdb->get_results(
                        "SELECT $table_name.post_title, $table_name.ID FROM {$table_name} WHERE $table_name.post_type = 'memberpressproduct' AND $table_name.post_status = 'publish'"
                    );
                    $prefs = $this->prefs;

                    ?>
                    <div class="hook-instance">
                        <div class="row">
                            <div class="col-lg-2 col-md-6 col-sm-6 col-xs-12">
                                <div class="form-group">
                                    <label for="<?php echo $this->field_id( 'creds' ); ?>"><?php echo $this->core->plural(); ?></label>
                                    <input type="text" name="<?php echo $this->field_name( 'creds' ); ?>" id="<?php echo $this->field_id( 'creds' ); ?>" value="<?php echo $this->core->number( $prefs['creds'] ); ?>" class="form-control" />
                                </div>
                            </div>
                            <div class="col-lg-4 col-md-6 col-sm-6 col-xs-12">
                                <div class="form-group">
                                    <label for="<?php echo $this->field_id( 'limit' ); ?>"><?php _e( 'Limit', 'mycred' ); ?></label>
                                    <?php echo $this->hook_limit_setting( $this->field_name( 'limit' ), $this->field_id( 'limit' ), $prefs['limit'] ); ?>
                                </div>
                            </div>
                            <div class="col-lg-4 col-md-6 col-sm-6 col-xs-12">
                                <div class="form-group">
                                    <label for="<?php echo $this->field_id( 'Select Product' ); ?>"><?php _e( 'Select Product', 'mycred' ); ?></label>
                                    <select name="<?= $this->field_name('product'); ?>" id="<?= $this->field_id( 'Select Product' ) ?>">
                                        <option value="">--Select Product--</option>
                                        <option selected="selected" value="all">All Products</option>
                                        <?php
                                        foreach ($results as $row)
                                        {
                                            $post_meta = get_post_meta($row->ID);
                                            $price = $post_meta['_mepr_product_price'][0];
                                            if($price > 0.00)
                                            {
                                                if($row->ID == $prefs['product'])
                                                {
                                                    echo '<option selected="selected" value="'.$row->ID.'">'.$row->post_title.'</option>';
                                                }
                                                else
                                                {
                                                    echo '<option value="'.$row->ID.'">'.$row->post_title.'</option>';
                                                }
                                            }
                                        }
                                        ?>
                                    </select>
                                </div>
                            </div>
                            <div class="col-lg-12 col-md-12 col-sm-12 col-xs-12">
                                <div class="form-group">
                                    <label for="<?php echo $this->field_id( 'log' ); ?>"><?php _e( 'Log Template', 'mycred' ); ?></label>
                                    <input type="text" name="<?php echo $this->field_name( 'log' ); ?>" id="<?php echo $this->field_id( 'log' ); ?>" placeholder="<?php _e( 'required', 'mycred' ); ?>" value="<?php echo esc_attr( $prefs['log'] ); ?>" class="form-control" />
                                    <span class="description"><?php echo $this->available_template_tags( array( 'general' ) ); ?></span>
                                </div>
                            </div>
                        </div>
                    </div>
                    <?php
                }

                /**
                 * Sanitise Preferences
                 * @since 1.6
                 * @version 1.0
                 */
                function sanitise_preferences( $data ) {

                    if ( isset( $data['limit'] ) && isset( $data['limit_by'] ) ) {
                        $limit = sanitize_text_field( $data['limit'] );
                        if ( $limit == '' ) $limit = 0;
                        $data['limit'] = $limit . '/' . $data['limit_by'];
                        unset( $data['limit_by'] );
                    }

                    return $data;

                }

            }
        endif;








        //Purchase OneTime/ Recurring Subscription
        if(!class_exists('MycredMembr_PurchaseSubsProduct')):
            class MycredMembr_PurchaseSubsProduct extends myCRED_Hook {

                /**
                 * Construct
                 * @param $hook_prefs
                 * @param string $type
                 */
                function __construct( $hook_prefs, $type = 'mycred_default' ) {
                    parent::__construct( array(
                        'id'       => 'onetime_recurr',
                        'defaults' => array(
                            'creds'   => 1,
                            'log'     => '%plural% for Purchasing OneTime or Recurring Product',
                            'limit'   => '1/d',
                            'product'   => 'recurring_checkbox'
                        )
                    ), $hook_prefs, $type );
                }

                /**
                 * Run
                 * @since 0.1
                 * @version 1.1
                 */
                public function run() {

                    // WordPress
                    add_action( 'mepr-event-non-recurring-transaction-completed', array( $this, 'one_time_recurr_product' ), 10, 2 );
                    add_action( 'mepr-event-recurring-transaction-completed', array( $this, 'recurring_subscription' ), 10, 2 );

                }

                public function recurring_subscription($event,$user_login = '')
                {
                    $prefs = $this->prefs;

                    if($prefs['product'] == 'recurring')
                    {
                        $user_ID = get_current_user_id();

                        $transaction = $event->get_data();

                        $member_user = $transaction;

                        $user_subscription = $member_user->product_id;

                        $is_first_real_payment = false;

                        if ($this->core->exclude_user($user_ID)) return;

                        $is_first_real_payment = false;

                        if ($transaction->amount > 0.00) {
                            $is_first_real_payment = true;
                        }
                        if ($is_first_real_payment) {
                            // Check for exclusion
                            if ($this->core->exclude_user($user_ID)) return;

                            // Limit
                            if (!$this->over_hook_limit('', 'recurring_subscription', $user_ID))
                                $this->core->add_creds(
                                    'recurring_subscription',
                                    $user_ID,
                                    $this->prefs['creds'],
                                    $this->prefs['log'],
                                    0,
                                    '',
                                    $this->mycred_type
                                );
                        }
                    }
                    else
                    {
                        return;
                    }
                }

                /**
                 * Login Hook
                 * @since 0.1
                 * @version 1.3
                 */

                public function one_time_recurr_product( $event,$user_login = '' )
                {
                    $user_ID = get_current_user_id();

                    $prefs = $this->prefs;

                    $transaction = $event->get_data();

                    $member_user = $transaction;

                    $user_subscription = $member_user->product_id;;

                    $is_first_real_payment = false;

                    if ($transaction->amount > 0.00) {
                        $is_first_real_payment = true;
                    }
                    if ($is_first_real_payment) {
                        // Check for exclusion
                        if ($this->core->exclude_user($user_ID)) return;

                        // Limit
                        if (!$this->over_hook_limit('', 'onetime_subscription', $user_ID))
                            $this->core->add_creds(
                                'onetime_subscription',
                                $user_ID,
                                $this->prefs['creds'],
                                $this->prefs['log'],
                                0,
                                '',
                                $this->mycred_type
                            );
                    }
                    else
                    {
                        return;
                    }
                }
                /**
                 * Preference for Login Hook
                 * @since 0.1
                 * @version 1.2
                 */
                public function preferences() {
                    $prefs = $this->prefs;

                    ?>
                    <div class="hook-instance">
                        <div class="row">
                            <div class="col-lg-2 col-md-6 col-sm-6 col-xs-12">
                                <div class="form-group">
                                    <label for="<?php echo $this->field_id( 'creds' ); ?>"><?php echo $this->core->plural(); ?></label>
                                    <input type="text" name="<?php echo $this->field_name( 'creds' ); ?>" id="<?php echo $this->field_id( 'creds' ); ?>" value="<?php echo $this->core->number( $prefs['creds'] ); ?>" class="form-control" />
                                </div>
                            </div>
                            <div class="col-lg-4 col-md-6 col-sm-6 col-xs-12">
                                <div class="form-group">
                                    <label for="<?php echo $this->field_id( 'limit' ); ?>"><?php _e( 'Limit', 'mycred' ); ?></label>
                                    <?php echo $this->hook_limit_setting( $this->field_name( 'limit' ), $this->field_id( 'limit' ), $prefs['limit'] ); ?>
                                </div>
                            </div>
                            <div class="col-lg-4 col-md-6 col-sm-6 col-xs-12">
                                <div class="form-group">
                                    <label for="<?php echo $this->field_id( 'recuring' ); ?>"><?php _e( 'Check for recurring', 'mycred' ); ?></label>
                                    <br>
                                    <input type="checkbox" name="<?= $this->field_name('product'); ?>" value="recurring" <?php if ($prefs['product'] == "recurring") echo "checked='checked'"; ?> id="<?= $this->field_id( 'recuring' ) ?>">
                                </div>
                            </div>
                            <div class="col-lg-12 col-md-12 col-sm-12 col-xs-12">
                                <div class="form-group">
                                    <label for="<?php echo $this->field_id( 'log' ); ?>"><?php _e( 'Log Template', 'mycred' ); ?></label>
                                    <input type="text" name="<?php echo $this->field_name( 'log' ); ?>" id="<?php echo $this->field_id( 'log' ); ?>" placeholder="<?php _e( 'required', 'mycred' ); ?>" value="<?php echo esc_attr( $prefs['log'] ); ?>" class="form-control" />
                                    <span class="description"><?php echo $this->available_template_tags( array( 'general' ) ); ?></span>
                                </div>
                            </div>
                        </div>
                    </div>
                    <?php
                }

                /**
                 * Sanitise Preferences
                 * @since 1.6
                 * @version 1.0
                 */
                function sanitise_preferences( $data ) {

                    if ( isset( $data['limit'] ) && isset( $data['limit_by'] ) ) {
                        $limit = sanitize_text_field( $data['limit'] );
                        if ( $limit == '' ) $limit = 0;
                        $data['limit'] = $limit . '/' . $data['limit_by'];
                        unset( $data['limit_by'] );
                    }

                    return $data;

                }

            }
        endif;
    });

}